/**
 * Copyright (c) 2000-present Liferay, Inc. All rights reserved.
 *
 * The contents of this file are subject to the terms of the Liferay Enterprise
 * Subscription License ("License"). You may not use this file except in
 * compliance with the License. You can obtain a copy of the License by
 * contacting Liferay, Inc. See the License for the specific language governing
 * permissions and limitations under the License, including but not limited to
 * distribution rights of the Software.
 *
 *
 *
 */

package com.liferay.custom.saml.resolvers;

import com.liferay.portal.kernel.log.Log;
import com.liferay.portal.kernel.log.LogFactoryUtil;
import com.liferay.portal.kernel.model.User;
import com.liferay.portal.kernel.service.ServiceContext;
import com.liferay.saml.opensaml.integration.resolver.UserResolver;

import java.util.Map;

import org.osgi.service.component.annotations.Activate;
import org.osgi.service.component.annotations.Component;
import org.osgi.service.component.annotations.Reference;

/**
 * @author Tibor Lipusz
 */
@Component(
	immediate = true,
	property = "serviceranking:Integer=" + (Integer.MIN_VALUE + 1),
	service = UserResolver.class
)
public class CustomUserResolver implements UserResolver {

	@Override
	public User resolveUser(
			UserResolverSAMLContext userResolverSAMLContext,
			ServiceContext serviceContext)
		throws Exception {

		if (_log.isDebugEnabled()) {
			_log.debug("Resolving");
		}

		// Implement custom resolver logic

		return _defaultUserResolver.resolveUser(
			userResolverSAMLContext, serviceContext);
	}

	@Reference(
		target = "(component.name=com.liferay.saml.opensaml.integration.internal.resolver.DefaultUserResolver)",
		unbind = "-"
	)
	public void setUserResolver(UserResolver userResolver) {
		_defaultUserResolver = userResolver;
	}

	@Activate
	protected void activate(Map<String, Object> properties) {
		if (_log.isDebugEnabled()) {
			_log.debug("Activated");

			_log.debug("Default resolver: " + _defaultUserResolver.getClass());
		}
	}

	private static final Log _log = LogFactoryUtil.getLog(
		CustomUserResolver.class);

	private UserResolver _defaultUserResolver;

}